@@ -88,7 +88,7 @@ alfa.contour <- function(m, s, a, n = 100, x = NULL, cont.line = FALSE) {
                    # Draw triangle in two dimensions
                    points(b[, 1], b[, 2],
                           type = "l",
-                          lwd = 4.5,
+                          lwd = 2,
                           col = "black");
                    # Add contour lines
                    if ( cont.line ) {
